@@ -17,11 +17,11 @@ App::Prove - Implements the C<prove> command.
 
 =head1 VERSION
 
-Version 3.16
+Version 3.18
 
 =cut
 
-$VERSION = '3.16';
+$VERSION = '3.18';
 
 =head1 DESCRIPTION
 
@@ -54,11 +54,12 @@ BEGIN {
     @ISA = qw(TAP::Object);
 
     @ATTR = qw(
-      archive argv blib show_count color directives exec failures fork
+      archive argv blib show_count color directives exec failures comments
       formatter harness includes modules plugins jobs lib merge parse quiet
       really_quiet recurse backwards shuffle taint_fail taint_warn timer
       verbose warnings_fail warnings_warn show_help show_man show_version
       state_class test_args state dry extension ignore_exit rules state_manager
+      normalize sources
     );
     __PACKAGE__->mk_methods(@ATTR);
 }
@@ -81,7 +82,9 @@ sub _initialize {
     my $args = shift || {};
 
     # setup defaults:
-    for my $key (qw( argv rc_opts includes modules state plugins rules )) {
+    for my $key (
+        qw( argv rc_opts includes modules state plugins rules sources ))
+    {
         $self->{$key} = [];
     }
     $self->{harness_class} = 'TAP::Harness';
@@ -132,8 +135,9 @@ sub add_rc_file {
     local *RC;
     open RC, "<$rc_file" or croak "Can't read $rc_file ($!)";
     while ( defined( my $line = <RC> ) ) {
-        push @{ $self->{rc_opts} }, grep $_ && $_ !~ /^#/,
-          $line =~ m{ ' ([^']*) ' | " ([^"]*) " | (\#.*) | (\S*) }xg;
+        push @{ $self->{rc_opts} },
+          grep { defined and not /^#/ }
+          $line =~ m{ ' ([^']*) ' | " ([^"]*) " | (\#.*) | (\S+) }xg;
     }
     close RC;
 }
@@ -195,12 +199,13 @@ sub process_args {
 
     {
         local @ARGV = @args;
-        Getopt::Long::Configure( 'no_ignore_case', 'bundling' );
+        Getopt::Long::Configure(qw(no_ignore_case bundling pass_through));
 
         # Don't add coderefs to GetOptions
         GetOptions(
             'v|verbose'   => \$self->{verbose},
             'f|failures'  => \$self->{failures},
+            'o|comments'  => \$self->{comments},
             'l|lib'       => \$self->{lib},
             'b|blib'      => \$self->{blib},
             's|shuffle'   => \$self->{shuffle},
@@ -212,10 +217,10 @@ sub process_args {
             'ext=s'       => \$self->{extension},
             'harness=s'   => \$self->{harness},
             'ignore-exit' => \$self->{ignore_exit},
+            'source=s@'   => $self->{sources},
             'formatter=s' => \$self->{formatter},
             'r|recurse'   => \$self->{recurse},
             'reverse'     => \$self->{backwards},
-            'fork'        => \$self->{fork},
             'p|parse'     => \$self->{parse},
             'q|quiet'     => \$self->{quiet},
             'Q|QUIET'     => \$self->{really_quiet},
@@ -236,6 +241,7 @@ sub process_args {
             't'           => \$self->{taint_warn},
             'W'           => \$self->{warnings_fail},
             'w'           => \$self->{warnings_warn},
+            'normalize'   => \$self->{normalize},
             'rules=s@'    => $self->{rules},
         ) or croak('Unable to continue');
 
@@ -272,7 +278,7 @@ sub _help {
 sub _color_default {
     my $self = shift;
 
-    return -t STDOUT && !IS_WIN32;
+    return -t STDOUT && !$ENV{HARNESS_NOTTY} && !IS_WIN32;
 }
 
 sub _get_args {
@@ -299,10 +305,6 @@ sub _get_args {
         $args{jobs} = $jobs;
     }
 
-    if ( my $fork = $self->fork ) {
-        $args{fork} = $fork;
-    }
-
     if ( my $harness_opt = $self->harness ) {
         $self->require_harness( harness => $harness_opt );
     }
@@ -311,6 +313,11 @@ sub _get_args {
         $args{formatter_class} = $formatter;
     }
 
+    for my $handler ( @{ $self->sources } ) {
+        my ( $name, $config ) = $self->_parse_source($handler);
+        $args{sources}->{$name} = $config;
+    }
+
     if ( $self->ignore_exit ) {
         $args{ignore_exit} = 1;
     }
@@ -340,7 +347,7 @@ sub _get_args {
 
     $args{verbosity} = shift @verb_adj || 0;
 
-    for my $a (qw( merge failures timer directives )) {
+    for my $a (qw( merge failures comments timer directives normalize )) {
         $args{$a} = 1 if $self->$a();
     }
 
@@ -412,6 +419,30 @@ sub _load_extensions {
     $self->_load_extension( $_, @search ) for @$ext;
 }
 
+sub _parse_source {
+    my ( $self, $handler ) = @_;
+
+    # Load any options.
+    ( my $opt_name = lc $handler ) =~ s/::/-/g;
+    local @ARGV = @{ $self->{argv} };
+    my %config;
+    Getopt::Long::GetOptions(
+        "$opt_name-option=s%" => sub {
+            my ( undef, $k, $v ) = @_;
+            if ( exists $config{$k} ) {
+                $config{$k} = [ $config{$k} ]
+                  unless ref $config{$k} eq 'ARRAY';
+                push @{ $config{$k} } => $v;
+            }
+            else {
+                $config{$k} = $v;
+            }
+        }
+    );
+    $self->{argv} = \@ARGV;
+    return ( $handler, \%config );
+}
+
 =head3 C<run>
 
 Perform whatever actions the command line args specified. The C<prove>
@@ -629,7 +660,7 @@ calling C<run>.
 
 =item C<failures>
 
-=item C<fork>
+=item C<comments>
 
 =item C<formatter>
 
