@@ -15,8 +15,10 @@ BEGIN {
     %VALIDATION_FOR = (
         directives => sub { shift; shift },
         verbosity  => sub { shift; shift },
+        normalize  => sub { shift; shift },
         timer      => sub { shift; shift },
         failures   => sub { shift; shift },
+        comments   => sub { shift; shift },
         errors     => sub { shift; shift },
         color      => sub { shift; shift },
         jobs       => sub { shift; shift },
@@ -41,15 +43,15 @@ BEGIN {
 
 =head1 NAME
 
-TAP::Formatter::Console - Harness output delegate for default console output
+TAP::Formatter::Base - Base class for harness output delegates
 
 =head1 VERSION
 
-Version 3.16
+Version 3.18
 
 =cut
 
-$VERSION = '3.16';
+$VERSION = '3.18';
 
 =head1 DESCRIPTION
 
@@ -132,7 +134,11 @@ Append run time for each test to output. Uses L<Time::HiRes> if available.
 
 =item * C<failures>
 
-Only show test failures (this is a no-op if C<verbose> is selected).
+Show test failures (this is a no-op if C<verbose> is selected).
+
+=item * C<comments>
+
+Show test comments (this is a no-op if C<verbose> is selected).
 
 =item * C<quiet>
 
@@ -157,7 +163,7 @@ true:
 =item * C<directives>
 
 If set to a true value, only test results with directives will be displayed.
-This overrides other settings such as C<verbose> or C<failures>.
+This overrides other settings such as C<verbose>, C<failures>, or C<comments>.
 
 =item * C<stdout>
 
@@ -200,7 +206,7 @@ sub prepare {
 
     my $longest = 0;
 
-    foreach my $test (@tests) {
+    for my $test (@tests) {
         $longest = length $test if length $test > $longest;
     }
 
@@ -242,6 +248,11 @@ sub open_test {
     die "Unimplemented.";
 }
 
+sub _output_success {
+    my ( $self, $msg ) = @_;
+    $self->_output($msg);
+}
+
 =head3 C<summary>
 
   $harness->summary( $aggregate );
@@ -272,14 +283,14 @@ sub summary {
     # the exit status is nonzero
 
     if ( $aggregate->all_passed ) {
-        $self->_output("All tests successful.\n");
+        $self->_output_success("All tests successful.\n");
     }
 
     # ~TODO option where $aggregate->skipped generates reports
     if ( $total != $passed or $aggregate->has_problems ) {
         $self->_output("\nTest Summary Report");
         $self->_output("\n-------------------\n");
-        foreach my $test (@$tests) {
+        for my $test (@$tests) {
             $self->_printed_summary_header(0);
             my ($parser) = $aggregate->parsers($test);
             $self->_output_summary_failure(
@@ -319,7 +330,7 @@ sub summary {
                     sprintf "  Parse errors: %s\n",
                     shift @errors
                 );
-                foreach my $error (@errors) {
+                for my $error (@errors) {
                     my $spaces = ' ' x 16;
                     $self->_failure_output("$spaces$error\n");
                 }
@@ -411,7 +422,7 @@ sub _range {
     @numbers = sort { $a <=> $b } @numbers;
     my ( $min, @range );
 
-    foreach my $i ( 0 .. $#numbers ) {
+    for my $i ( 0 .. $#numbers ) {
         my $num  = $numbers[$i];
         my $next = $numbers[ $i + 1 ];
         if ( defined $next && $next == $num + 1 ) {
