@@ -14,11 +14,11 @@ TAP::Formatter::Console - Harness output delegate for default console output
 
 =head1 VERSION
 
-Version 3.16
+Version 3.18
 
 =cut
 
-$VERSION = '3.16';
+$VERSION = '3.18';
 
 =head1 DESCRIPTION
 
@@ -31,7 +31,7 @@ This provides console orientated output formatting for TAP::Harness.
 
 =head2 C<< open_test >>
 
-See L<TAP::Formatter::base>
+See L<TAP::Formatter::Base>
 
 =cut
 
@@ -70,6 +70,13 @@ sub _set_colors {
     }
 }
 
+sub _output_success {
+    my ( $self, $msg ) = @_;
+    $self->_set_colors('green');
+    $self->_output($msg);
+    $self->_set_colors('reset');
+}
+
 sub _failure_output {
     my $self = shift;
     $self->_set_colors('red');
