@@ -13,11 +13,11 @@ TAP::Formatter::File::Session - Harness output delegate for file output
 
 =head1 VERSION
 
-Version 3.16
+Version 3.18
 
 =cut
 
-$VERSION = '3.16';
+$VERSION = '3.18';
 
 =head1 DESCRIPTION
 
@@ -52,12 +52,13 @@ sub result {
     }
 
     if (!$formatter->quiet
-        && (   ( $formatter->verbose && !$formatter->failures )
+        && (   $formatter->verbose
             || ( $result->is_test && $formatter->failures && !$result->is_ok )
+            || ( $formatter->comments   && $result->is_comment )
             || ( $result->has_directive && $formatter->directives ) )
       )
     {
-        $self->{results} .= $result->as_string . "\n";
+        $self->{results} .= $self->_format_for_output($result) . "\n";
     }
 }
 
