@@ -9,11 +9,11 @@ TAP::Object - Base class that provides common functionality to all C<TAP::*> mod
 
 =head1 VERSION
 
-Version 3.16
+Version 3.18
 
 =cut
 
-$VERSION = '3.16';
+$VERSION = '3.18';
 
 =head1 SYNOPSIS
 
@@ -93,6 +93,25 @@ sub _croak {
     return;
 }
 
+=head3 C<_confess>
+
+Raise an exception using C<confess> from L<Carp>, eg:
+
+    $self->_confess( 'why me?', 'aaarrgh!' );
+
+May also be called as a I<class> method.
+
+    $class->_confess( 'this works too' );
+
+=cut
+
+sub _confess {
+    my $proto = shift;
+    require Carp;
+    Carp::confess(@_);
+    return;
+}
+
 =head3 C<_construct>
 
 Create a new instance of the specified class.
@@ -124,7 +143,7 @@ Create simple getter/setters.
 
 sub mk_methods {
     my ( $class, @methods ) = @_;
-    foreach my $method_name (@methods) {
+    for my $method_name (@methods) {
         my $method = "${class}::$method_name";
         no strict 'refs';
         *$method = sub {
