@@ -15,27 +15,27 @@ TAP::Parser::Grammar - A grammar for the Test Anything Protocol.
 
 =head1 VERSION
 
-Version 3.16
+Version 3.18
 
 =cut
 
-$VERSION = '3.16';
+$VERSION = '3.18';
 
 =head1 SYNOPSIS
 
   use TAP::Parser::Grammar;
   my $grammar = $self->make_grammar({
-    stream  => $tap_parser_stream,
-    parser  => $tap_parser,
-    version => 12,
+    iterator => $tap_parser_iterator,
+    parser   => $tap_parser,
+    version  => 12,
   });
 
   my $result = $grammar->tokenize;
 
 =head1 DESCRIPTION
 
-C<TAP::Parser::Grammar> tokenizes lines from a TAP stream and constructs
-L<TAP::Parser::Result> subclasses to represent the tokens.
+C<TAP::Parser::Grammar> tokenizes lines from a L<TAP::Parser::Iterator> and
+constructs L<TAP::Parser::Result> subclasses to represent the tokens.
 
 Do not attempt to use this class directly.  It won't make sense.  It's mainly
 here to ensure that we will be able to have pluggable grammars when TAP is
@@ -49,22 +49,24 @@ parser).
 =head3 C<new>
 
   my $grammar = TAP::Parser::Grammar->new({
-      stream  => $stream,
-      parser  => $parser,
-      version => $version,
+      iterator => $iterator,
+      parser   => $parser,
+      version  => $version,
   });
 
-Returns L<TAP::Parser> grammar object that will parse the specified stream.
-Both C<stream> and C<parser> are required arguments.  If C<version> is not set
-it defaults to C<12> (see L</set_version> for more details).
+Returns L<TAP::Parser> grammar object that will parse the TAP stream from the
+specified iterator.  Both C<iterator> and C<parser> are required arguments.
+If C<version> is not set it defaults to C<12> (see L</set_version> for more
+details).
 
 =cut
 
 # new() implementation supplied by TAP::Object
 sub _initialize {
     my ( $self, $args ) = @_;
-    $self->{stream} = $args->{stream};    # TODO: accessor
-    $self->{parser} = $args->{parser};    # TODO: accessor
+    $self->{iterator} = $args->{iterator};    # TODO: accessor
+    $self->{iterator} ||= $args->{stream};    # deprecated
+    $self->{parser} = $args->{parser};        # TODO: accessor
     $self->set_version( $args->{version} || 12 );
     return $self;
 }
@@ -105,7 +107,7 @@ my %language_for;
                     $skip = 'SKIP';
 
                     # If we can't match # SKIP the directive should be undef.
-                    ($explanation) = $tail =~ /^#\s*SKIP\s+(.*)/i;
+                    ($explanation) = $tail =~ /^#\s*SKIP\S*\s+(.*)/i;
                 }
                 elsif ( $tail !~ /^\s*$/ ) {
                     return $self->_make_unknown_token($line);
@@ -218,7 +220,7 @@ my %language_for;
         '13' => {
             tokens => \%v13,
             setup  => sub {
-                shift->{stream}->handle_unicode;
+                shift->{iterator}->handle_unicode;
             },
         },
     );
@@ -284,7 +286,7 @@ current line of TAP.
 sub tokenize {
     my $self = shift;
 
-    my $line = $self->{stream}->next;
+    my $line = $self->{iterator}->next;
     unless ( defined $line ) {
         delete $self->{parser};    # break circular ref
         return;
@@ -292,7 +294,7 @@ sub tokenize {
 
     my $token;
 
-    foreach my $token_data ( @{ $self->{ordered_tokens} } ) {
+    for my $token_data ( @{ $self->{ordered_tokens} } ) {
         if ( $line =~ $token_data->{syntax} ) {
             my $handler = $token_data->{handler};
             $token = $self->$handler($line);
@@ -351,7 +353,7 @@ TAP parsing loop looks similar to the following:
  my @tokens;
  my $grammar = TAP::Grammar->new;
  LINE: while ( defined( my $line = $parser->_next_chunk_of_tap ) ) {
-     foreach my $type ( $grammar->token_types ) {
+     for my $type ( $grammar->token_types ) {
          my $syntax  = $grammar->syntax_for($type);
          if ( $line =~ $syntax ) {
              my $handler = $grammar->handler_for($type);
@@ -443,7 +445,7 @@ sub _make_yaml_token {
 
     my $yaml = TAP::Parser::YAMLish::Reader->new;
 
-    my $stream = $self->{stream};
+    my $iterator = $self->{iterator};
 
     # Construct a reader that reads from our input stripping leading
     # spaces from each line.
@@ -452,7 +454,7 @@ sub _make_yaml_token {
     my @extra  = ($marker);
     my $reader = sub {
         return shift @extra if @extra;
-        my $line = $stream->next;
+        my $line = $iterator->next;
         return $2 if $line =~ $strip;
         return;
     };
