@@ -9,21 +9,18 @@ use TAP::Parser::Iterator ();
 
 =head1 NAME
 
-TAP::Parser::Iterator::Array - Internal TAP::Parser array Iterator
+TAP::Parser::Iterator::Array - Iterator for array-based TAP sources
 
 =head1 VERSION
 
-Version 3.16
+Version 3.18
 
 =cut
 
-$VERSION = '3.16';
+$VERSION = '3.18';
 
 =head1 SYNOPSIS
 
-  # see TAP::Parser::IteratorFactory for preferred usage
-
-  # to use directly:
   use TAP::Parser::Iterator::Array;
   my @data = ('foo', 'bar', baz');
   my $it   = TAP::Parser::Iterator::Array->new(\@data);
@@ -32,8 +29,8 @@ $VERSION = '3.16';
 =head1 DESCRIPTION
 
 This is a simple iterator wrapper for arrays of scalar content, used by
-L<TAP::Parser>.  Unless you're subclassing, you probably won't need to use
-this module directly.
+L<TAP::Parser>.  Unless you're writing a plugin or subclassing, you probably
+won't need to use this module directly.
 
 =head1 METHODS
 
@@ -100,7 +97,6 @@ Originally ripped off from L<Test::Harness>.
 L<TAP::Object>,
 L<TAP::Parser>,
 L<TAP::Parser::Iterator>,
-L<TAP::Parser::IteratorFactory>,
 
 =cut
 
