@@ -1,10 +1,12 @@
 package TAP::Parser::SourceHandler;
 
 use strict;
-use warnings;
+use vars qw($VERSION @ISA);
 
+use TAP::Object           ();
 use TAP::Parser::Iterator ();
-use base 'TAP::Object';
+
+@ISA = qw(TAP::Object);
 
 =head1 NAME
 
@@ -12,11 +14,11 @@ TAP::Parser::SourceHandler - Base class for different TAP source handlers
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.18
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.18';
 
 =head1 SYNOPSIS
 
@@ -25,7 +27,7 @@ our $VERSION = '3.51_01';
 
   # must be sub-classed for use
   package MySourceHandler;
-  use base 'TAP::Parser::SourceHandler';
+  use base qw( TAP::Parser::SourceHandler );
   sub can_handle    { return $confidence_level }
   sub make_iterator { return $iterator }
 
@@ -103,12 +105,12 @@ a quick overview.
 
 Start by familiarizing yourself with L<TAP::Parser::Source> and
 L<TAP::Parser::IteratorFactory>.  L<TAP::Parser::SourceHandler::RawTAP> is
-the easiest sub-class to use as an example.
+the easiest sub-class to use an an example.
 
 It's important to point out that if you want your subclass to be automatically
 used by L<TAP::Parser> you'll have to and make sure it gets loaded somehow.
 If you're using L<prove> you can write an L<App::Prove> plugin.  If you're
-using L<TAP::Parser> or L<TAP::Harness> directly (e.g. through a custom script,
+using L<TAP::Parser> or L<TAP::Harness> directly (eg. through a custom script,
 L<ExtUtils::MakeMaker>, or L<Module::Build>) you can use the C<config> option
 which will cause L<TAP::Parser::IteratorFactory/load_sources> to load your
 subclass).
@@ -121,11 +123,12 @@ L<TAP::Parser::IteratorFactory/register_handler>.
   package MySourceHandler;
 
   use strict;
+  use vars '@ISA'; # compat with older perls
 
   use MySourceHandler; # see TAP::Parser::SourceHandler
   use TAP::Parser::IteratorFactory;
 
-  use base 'TAP::Parser::SourceHandler';
+  @ISA = qw( TAP::Parser::SourceHandler );
 
   TAP::Parser::IteratorFactory->register_handler( __PACKAGE__ );
 
