@@ -1,14 +1,13 @@
 package TAP::Parser::SourceHandler::Executable;
 
 use strict;
-use warnings;
-
-use File::Spec;
+use vars qw($VERSION @ISA);
 
+use TAP::Parser::SourceHandler     ();
 use TAP::Parser::IteratorFactory   ();
 use TAP::Parser::Iterator::Process ();
 
-use base 'TAP::Parser::SourceHandler';
+@ISA = qw(TAP::Parser::SourceHandler);
 
 TAP::Parser::IteratorFactory->register_handler(__PACKAGE__);
 
@@ -18,11 +17,11 @@ TAP::Parser::SourceHandler::Executable - Stream output from an executable TAP so
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.18
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.18';
 
 =head1 SYNOPSIS
 
@@ -40,13 +39,13 @@ our $VERSION = '3.51_01';
 
 This is an I<executable> L<TAP::Parser::SourceHandler> - it has 2 jobs:
 
-1. Figure out if the L<TAP::Parser::Source> it's given is an executable
-   command (L</can_handle>).
+1. Figure out if the L<TAP::Parser::Source> it's given is an executable command
+(L</can_handle>).
 
 2. Creates an iterator for executable commands (L</make_iterator>).
 
-Unless you're writing a plugin or subclassing L<TAP::Parser>, you
-probably won't need to use this module directly.
+Unless you're writing a plugin or subclassing L<TAP::Parser>, you probably
+won't need to use this module directly.
 
 =head1 METHODS
 
@@ -56,10 +55,10 @@ probably won't need to use this module directly.
 
   my $vote = $class->can_handle( $source );
 
-Only votes if $source looks like an executable file. Casts the
-following votes:
+Only votes if $source looks like an executable file.  Casts the following votes:
 
   0.9  if it's a hash with an 'exec' key
+  0.8  if it's a .sh file
   0.8  if it's a .bat file
   0.75 if it's got an execute bit set
 
@@ -72,9 +71,10 @@ sub can_handle {
     if ( $meta->{is_file} ) {
         my $file = $meta->{file};
 
-        return 0.85 if $file->{execute} && $file->{binary};
+        # Note: we go in low so we can be out-voted
+        return 0.8 if $file->{lc_ext} eq '.sh';
         return 0.8 if $file->{lc_ext} eq '.bat';
-        return 0.25 if $file->{execute};
+        return 0.7 if $file->{execute};
     }
     elsif ( $meta->{is_hash} ) {
         return 0.9 if $src->raw->{exec};
@@ -109,8 +109,7 @@ sub make_iterator {
         @command = @{ $source->raw->{exec} || [] };
     }
     elsif ( $meta->{is_scalar} ) {
-        @command = File::Spec->rel2abs( ${ $source->raw } )
-          if ${ $source->raw };
+        @command = ${ $source->raw };
     }
     elsif ( $meta->{is_array} ) {
         @command = @{ $source->raw };
@@ -121,8 +120,6 @@ sub make_iterator {
     $class->_autoflush( \*STDOUT );
     $class->_autoflush( \*STDERR );
 
-    push @command, @{ $source->test_args || [] };
-
     return $class->iterator_class->new(
         {   command => \@command,
             merge   => $source->merge
@@ -158,11 +155,12 @@ Please see L<TAP::Parser/SUBCLASSING> for a subclassing overview.
   package MyRubySourceHandler;
 
   use strict;
+  use vars '@ISA';
 
   use Carp qw( croak );
   use TAP::Parser::SourceHandler::Executable;
 
-  use base 'TAP::Parser::SourceHandler::Executable';
+  @ISA = qw( TAP::Parser::SourceHandler::Executable );
 
   # expect $handler->(['mytest.rb', 'cmdline', 'args']);
   sub make_iterator {
