@@ -27,6 +27,7 @@ use vars qw(
   $Directives
   $Timer
   $Strap
+  $HarnessSubclass
   $has_time_hires
   $IgnoreExit
 );
@@ -44,11 +45,11 @@ Test::Harness - Run Perl standard test scripts with statistics
 
 =head1 VERSION
 
-Version 3.16
+Version 3.18
 
 =cut
 
-$VERSION = '3.16';
+$VERSION = '3.18';
 
 # Backwards compatibility for exportable variable names.
 *verbose  = *Verbose;
@@ -207,9 +208,10 @@ sub _new_harness {
     my $sub_args = shift || {};
 
     my ( @lib, @switches );
-    for my $opt ( split_shell( $Switches, $ENV{HARNESS_PERL_SWITCHES} ) ) {
+    my @opt = split_shell( $Switches, $ENV{HARNESS_PERL_SWITCHES} );
+    while ( my $opt = shift @opt ) {
         if ( $opt =~ /^ -I (.*) $ /x ) {
-            push @lib, $1;
+            push @lib, length($1) ? $1 : shift @opt;
         }
         else {
             push @switches, $opt;
@@ -240,9 +242,6 @@ sub _new_harness {
             if ( $opt =~ /^j(\d*)$/ ) {
                 $args->{jobs} = $1 || 9;
             }
-            elsif ( $opt eq 'f' ) {
-                $args->{fork} = 1;
-            }
             elsif ( $opt eq 'c' ) {
                 $args->{color} = 1;
             }
@@ -252,7 +251,8 @@ sub _new_harness {
         }
     }
 
-    return TAP::Harness->new($args);
+    my $class = $ENV{HARNESS_SUBCLASS} || 'TAP::Harness';
+    return TAP::Harness->_construct( $class, $args );
 }
 
 # Get the parts of @INC which are changed from the stock list AND
@@ -270,7 +270,7 @@ sub _filtered_inc {
     elsif (IS_WIN32) {
 
         # Lose any trailing backslashes in the Win32 paths
-        s/[\\\/]+$// foreach @inc;
+        s/[\\\/]+$// for @inc;
     }
 
     my @default_inc = _default_inc();
@@ -307,7 +307,7 @@ sub _filtered_inc {
         my $perl = $ENV{HARNESS_PERL} || $^X;
 
         # Avoid using -l for the benefit of Perl 6
-        chomp( @inc = `$perl -e "print join qq[\\n], \@INC, q[]"` );
+        chomp( @inc = `"$perl" -e "print join qq[\\n], \@INC, q[]"` );
         return @inc;
     }
 }
@@ -530,15 +530,19 @@ Provide additional options to the harness. Currently supported options are:
 
 Run <n> (default 9) parallel jobs.
 
-=item C<< f >>
+=item C<< c >>
 
-Use forked parallelism.
+Try to color output. See L<TAP::Formatter::Base/"new">.
 
 =back
 
 Multiple options may be separated by colons:
 
-    HARNESS_OPTIONS=j9:f make test
+    HARNESS_OPTIONS=j9:c make test
+
+=item C<HARNESS_SUBCLASS>
+
+Specifies a TAP::Harness subclass to be used in place of TAP::Harness.
 
 =back
 
